function RES=DiagCriteria(Freq,Type,Code,NumSpec,SetInst)

%This function compute the contribution of the first eigenvalue to the variance of normalized residuals, 
%the number of omitted factors, the contributions of the first k and of the
%k+1 eigenvalues, and the penalty term.

%INPUT:
%Freq= 1: monthly; 2: quarterly;
%Type= 1: financial models; 2: macroeconomic models;
%Code= 10: time-invariant specifications; 11: time-varying specification
%NumSpec=specification number: 
%for financial models:NumSpec= 1 CAPM, 2 FF, 3 CAR, 4 5FF, 5 HXZ, 6 FF and QMJ, 7 FF and BAB (see Table 1);
%for macroeconomic models: NumSpec= 1 CCAPM, 2 EZ, 3 NDC and DC, 4 YO, 5 LVX (see Table 2)
%SetInst= seto of isntruments involved in the conditional specification: 1 Z_t-1={1,divY_t-1}, 2 Z_t-1={1,divY_t-1} and Z_{i,t-1}=bm_{i,t-1}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if Code==10 %Time invariant models
    fname=sprintf('ESTRES_Freq%d_Type%d_Code%d_Spec%d',Freq,Type,Code,NumSpec);    
else        %Time-varying models
    fname=sprintf('ESTRES_Freq%d_Type%d_Code%d_Spec%d_SetInst%d',Freq,Type,Code,NumSpec,SetInst);    
end
load(fname,'n','nchi','T','Ti','res','I','ExcR');

if Code~=10; T=T-1; end;   %Re-defintion of the number of observations for the time-varying spec

%Standardized residuals
m=sum(res)./T;		%average, it is zero.
v=var(res);         %variance
resSt=I.*((res-repmat(m,T,1))./repmat(sqrt(v),T,1));	%standardized residuals, Txn

D=(resSt*resSt')/(nchi*T);   %TxT var-cov matrix of fitted residuals
Eig=sort(eig(D),'descend');  %Tx1 vector of eigenvalues in descend order

p=((sqrt(nchi)+sqrt(T))^2/(nchi*T))*log((nchi*T)/(sqrt(nchi)+sqrt(T))^2);   %Penalty function
k=find(Eig<p,1)-1;      %number of omitted factors
cum=sum(Eig(1:k));      %cumulated contribution in percentage of the k largest eigenvalues.

RES=[NumSpec,nchi,Eig(1,1)*100,k,cum*100,Eig(k+1,1)*100,p*100]; 


%Figures 1 and 2 in the paper
if        Freq==1 && Type==1 && Code==10 && NumSpec==1 && SetInst==0; %Time-invariant CAPM
    figure (1)      % Time-invariant CAPM
    ScreePlot(Eig(1:1:5,1),p)
elseif    Freq==1 && Type==1 && Code==11 && NumSpec==1 && SetInst==1; %Time-varying (i) CAPM 
    figure (2)      % Time-varying CAPM    
    ScreePlot(Eig(1:1:5,1),p)
elseif    Freq==1 && Type==1 && Code==10 && NumSpec==2 && SetInst==0; %Time-invariant FF
    figure (3)      % Time-invariant FF    
    ScreePlot(Eig(1:1:5,1),p)
elseif    Freq==1 && Type==1 && Code==11 && NumSpec==2 && SetInst==1; %Time-varying (i) FF  
    figure (4)      % Time-varying FF    
    ScreePlot(Eig(1:1:5,1),p)
end