
%% ========================================================================
%% A DIAGNOSTIC CRITERION FOR APPROXIMATE FACTOR STRUCTURE
%% P.Gagliardini, E.Ossola, O.Scaillet
%% September 2014
%% ========================================================================
clc;
clear;

%This function computes the diagnostic criteria for 
%the linear factor models listed in Tables 1 and 2.
%The results are reported in Tables 4 and 5 in the papers.
%TAB%_% reports the following output:
%1col: specification number
%2col: trimmed cross-sectional dimension
%3col: the largest eigenvalue
%4col: the number of omitted common factors
%5col: the contribution of the first k eigenvalues
%6col: the (k+1)-eigenvalue
%7col: the penalty function.
%The results are reported in percentage.

%Financial linear factor models, monthly data: (see Table 1)
%CAPM, FF, CAR, 5FF, HXZ, FF and QMJ, FF and BAB
TAB4_A=zeros(7,7);
TAB4_Bi=zeros(7,7);
TAB4_Bii=zeros(7,7);
for s=1:7;
    TAB4_A(s,:)=DiagCriteria(1,1,10,s,0);           %Time-invariant models
    TAB4_Bi(s,:)=DiagCriteria(1,1,11,s,1);          %Time-varying set (i)
    TAB4_Bii(s,:)=DiagCriteria(1,1,11,s,2);         %Time-varying set (ii)    
end;
display(TAB4_A,'Table 4, Panel A, Time-invariant financial models');
display(TAB4_Bi,'Table 4, Panel B, Time-varying (i) financial models');
display(TAB4_Bii,'Table 4, Panel B, Time-varying (ii) financial models');

%Macroeconomic linear factor models, quartely data: (see Table 2)
%CCAPM, EZ, NDC and DC, YO, LVX
TAB5=zeros(6,7);
for s=1:5;
    TAB5(s,:)=DiagCriteria(2,2,10,s,0);    %Time-invariant models
end;
% CRR, monthly data
    TAB5(6,:)=DiagCriteria(1,2,10,6,0);        %Time-invariant model
display(TAB5, 'Table 5, Time-invariant macroeconomic models');

% Time-invariant CAPM with quarterly data - see Section 6.3
CAPMq=DiagCriteria(2,1,10,1,0);


  
%% Additional results    
%Financial linear factor models, monthly data:
TABX=zeros(5,7); TABXi=zeros(5,7); TABXii=zeros(5,7);
for s=8:12
    TABX(s,:)=DiagCriteria(1,1,10,s,0);    %Time-invariant models
    TABXi(s,:)=DiagCriteria(1,1,11,s,1);    %Time-varying set (i)
    TABXii(s,:)=DiagCriteria(1,1,11,s,2);    %Time-varying set (ii)
end;


 
