function [Z,Zi,d1,d2,AssBeta]=InstrumentalChoice(T,n,K,Ti,BM,I,Freq,SetInst)
% This function defines the set of instruments involved in the conditional specification

% COMMON ISTRUMENTS
if Freq==1; %monthly data
    load  Wspace_FactorsM CRR Rf DivYields
else        %quarterly data
    load  Wspace_FactorsQ SV CRR Rf DivYields CAY
end;
%Standardized instruments
DefSpread=CRR(:,5);
TermSpread=CRR(:,4);
ds=(DefSpread-mean(DefSpread))./std(DefSpread);       
ts=(TermSpread-mean(TermSpread))./std(TermSpread);    
dY=(DivYields-mean(DivYields))./std(DivYields); 
rf=(Rf-mean(Rf))./std(Rf);     
if Freq==2; 
Lc=SV(:,1);
cay=(CAY-mean(CAY))./std(CAY);  	
lc=(Lc-mean(Lc))./std(Lc);  
end;  
% Z vector of common instruemnts
% p number of common instruments Z
% q number of asset-specific instruments Zi
% Definition of functional specifications:
% AssBeta=1 \b_{i,t}=B_{i}*Z_{t-1}+C_{i}*Z_{i,t-1}; \lambda_{t}=\Lamdba*Z_{t-1}
% AssBeta=2 \b_{i,t}=B_{i}*Z_{t-1}                  \lambda_{t}=\Lamdba*Z_{t-1}
if   	SetInst==1;  Z=[ones(T,1),dY]; p=2; q=0; AssBeta=2;         %case (i) in the paper
                    d1=p*(p+1)/2; d2=K*p;			% Definition of dimensions d1,d2 - Section 3.1 (GOS(2016))	
elseif  SetInst==2;  Z=[ones(T,1),dY]; p=2; q=1; AssBeta=1;         %case (ii) in the paper            
                    d1=p*(p+1)/2+p*q; d2=K*(p+q);	% Definition of dimensions d1,d2 - Section 3.1 (GOS(2016))
end;    

% ASSET SPECIFIC INSTRUMENT: book-to-market equity - definition of the
% matrix Zi
Zi=zeros(T,q,n);
if q==1;       
    for i=1:n;
        if sum(BM(:,i))~=0;  %This condition is apply on quarterly data
            %Standardiz. of BM (book-to-mkt)
            m=sum(BM(:,i))/Ti(i);
            s=sqrt(sum((BM(:,i)-I(:,i).*repmat(m,T,1)).^2)/Ti(i));
            if s==0; %This happens when BM is constant over the Ti observations
                z1=I(:,i).*((BM(:,i)-m));   %recentering
            else
                z1=I(:,i).*((BM(:,i)-m)/s); %standardization
            end;
            Zi(:,:,i)=z1;
        end;
    end;
end;
